@@ -1,4 +1,5 @@
 import autofit as af
+import autogalaxy as ag
 from astropy import cosmology as cosmo
 from autogalaxy.pipeline.phase import dataset
 from autogalaxy.pipeline.phase.imaging.phase import PhaseAttributes as AgPhaseAttributes
@@ -6,6 +7,7 @@ from autolens.pipeline.phase.settings import PhaseSettingsImaging
 from autolens.pipeline.phase.imaging.analysis import Analysis
 from autolens.pipeline.phase.imaging.meta_imaging import MetaImaging
 from autolens.pipeline.phase.imaging.result import Result
+from autolens.pipeline.phase.extensions.stochastic_phase import StochasticPhase
 
 
 class PhaseImaging(dataset.PhaseDataset):
@@ -106,6 +108,32 @@ class PhaseImaging(dataset.PhaseDataset):
 
         return analysis
 
+    def extend_with_stochastic_phase(
+        self,
+        stochastic_search=None,
+        include_lens_light=False,
+        include_pixelization=False,
+        include_regularization=False,
+    ):
+
+        if stochastic_search is None:
+            stochastic_search = self.search
+
+        model_classes = [ag.mp.MassProfile]
+
+        if include_lens_light:
+            model_classes.append(ag.lp.LightProfile)
+
+        if include_pixelization:
+            model_classes.append(ag.pix.Pixelization)
+
+        if include_regularization:
+            model_classes.append(ag.reg.Regularization)
+
+        return StochasticPhase(
+            phase=self, search=stochastic_search, model_classes=tuple(model_classes)
+        )
+
     def output_phase_info(self):
 
         file_phase_info = "{}/{}".format(self.search.paths.output_path, "phase.info")
