@@ -1,9 +1,9 @@
+import os
+
 import autofit as af
 import autolens as al
 
-import os
-
-# The pixel scale of the image to be simulated
+"""The pixel scale of dataset to be simulated."""
 pixel_scales = 0.1
 
 grid = al.Grid.uniform(shape_2d=(50, 50), pixel_scales=pixel_scales, sub_size=1)
@@ -15,17 +15,16 @@ print(grid)
 lens_galaxy = al.Galaxy(
     redshift=0.5,
     mass=al.mp.EllipticalIsothermal(
-        centre=(0.0, 0.0), phi=45.0, axis_ratio=0.8, einstein_radius=1.0
+        centre=(0.0, 0.0), elliptical_comps=(0.111111, 0.0), einstein_radius=1.0
     ),
-    shear=al.mp.ExternalShear(magnitude=0.05, phi=90.0),
+    shear=al.mp.ExternalShear(elliptical_comps=(0.0, 0.05)),
 )
 
 source_galaxy = al.Galaxy(
     redshift=1.0,
     light=al.lp.EllipticalSersic(
         centre=(0.1, 0.1),
-        axis_ratio=0.8,
-        phi=60.0,
+        elliptical_comps=(0.096225, -0.055555),
         intensity=0.3,
         effective_radius=1.0,
         sersic_index=2.5,
@@ -33,7 +32,7 @@ source_galaxy = al.Galaxy(
 )
 
 
-# Use these galaxies to setup a tracer, which will generate the image for the simulated imaging dataset.
+"""Use these galaxies to setup a tracer, which will generate the image for the simulated imaging dataset."""
 tracer = al.Tracer.from_galaxies(galaxies=[lens_galaxy, source_galaxy])
 
 deflections = tracer.deflections_from_grid(grid=grid)
